aboutsummaryrefslogtreecommitdiffstats
path: root/erts/emulator/pcre/local_config.h
diff options
context:
space:
mode:
authorRickard Green <[email protected]>2017-03-27 14:39:49 +0200
committerRickard Green <[email protected]>2017-04-05 14:36:43 +0200
commit74f11bdee247626ed6a3afe558bde4989687e642 (patch)
treea4ca0966d941c35f94825a73d7191ea96f34d4f6 /erts/emulator/pcre/local_config.h
parenta748cafdc7063d9f181ba12088db6458793ced2f (diff)
downloadotp-74f11bdee247626ed6a3afe558bde4989687e642.tar.gz
otp-74f11bdee247626ed6a3afe558bde4989687e642.tar.bz2
otp-74f11bdee247626ed6a3afe558bde4989687e642.zip
Update PCRE to version 8.40
Diffstat (limited to 'erts/emulator/pcre/local_config.h')
-rw-r--r--erts/emulator/pcre/local_config.h12
1 files changed, 10 insertions, 2 deletions
diff --git a/erts/emulator/pcre/local_config.h b/erts/emulator/pcre/local_config.h
index 791d7f5a6b..6a0b7b4d4d 100644
--- a/erts/emulator/pcre/local_config.h
+++ b/erts/emulator/pcre/local_config.h
@@ -55,6 +55,11 @@
--disable-stack-for-recursion). */
#define NO_RECURSE
+/* The value of PARENS_NEST_LIMIT specifies the maximum depth of nested
+ parentheses (of any kind) in a pattern. This limits the amount of system
+ stack that is used while compiling a pattern. */
+#define PARENS_NEST_LIMIT 250
+
/* Define if linking statically (TODO: make nice with Libtool) */
#define PCRE_STATIC 1
@@ -74,8 +79,11 @@
/* Define to enable support for Unicode properties */
#define SUPPORT_UCP
-/* Define to enable support for the UTF-8 Unicode encoding. */
+/* Define to any value to enable support for the UTF-8/16/32 Unicode encoding.
+ This will work even in an EBCDIC environment, but it is incompatible with
+ the EBCDIC macro. That is, PCRE can support *either* EBCDIC code *or*
+ ASCII/UTF-8/16/32, but not both at once. */
#define SUPPORT_UTF
/* Version number of package */
-#define VERSION "8.33"
+#define VERSION "8.40"